@@ -105,7 +105,7 @@ class OpenStackDriver(AbstractSystemsDriver):
 
     def _get_instance_image_id(self, instance):
         # instance.image.id is always None for boot from volume instance
-        image_id = instance.image.id
+        image_id = instance.image.get('id')
 
         if image_id is None and len(instance.attached_volumes) > 0:
             vol = self._get_volume_info(instance.attached_volumes[0].id)
@@ -145,7 +145,7 @@ class OpenStackDriver(AbstractSystemsDriver):
 
         :returns: list of UUIDs representing the systems
         """
-        return [server.id for server in self._cc.list_servers()]
+        return [server.id for server in self._cc.list_servers(bare=True)]
 
     def uuid(self, identity):
         """Get computer system UUID by name
@@ -198,6 +198,17 @@ class OpenStackDriver(AbstractSystemsDriver):
 
         """
         instance = self._get_instance(identity)
+        delayed_media_eject = instance.metadata.get('sushy-tools-delay-eject')
+
+        if delayed_media_eject:
+            self._logger.debug(
+                'Create task to rebuild with blank-image for %(identity)s' %
+                {'identity': identity})
+            # Not running async here, as long as the blank image used is small
+            # this should finish in ~20 seconds.
+            self._submit_future(
+                False, self._rebuild_with_blank_image, identity)
+            self._remove_delayed_eject_metadata(identity)
 
         if instance.task_state is not None:
             # SYS518 is used here to trick openstack/sushy to do retries.
@@ -297,7 +308,7 @@ class OpenStackDriver(AbstractSystemsDriver):
         instance = self._get_instance(identity)
 
         hw_firmware_type = None
-        if instance.image['id'] is not None:
+        if instance.image.get('id') is not None:
             image = self._get_image_info(instance.image['id'])
             hw_firmware_type = getattr(image, 'hw_firmware_type', None)
         elif len(instance.attached_volumes) > 0:
@@ -337,7 +348,7 @@ class OpenStackDriver(AbstractSystemsDriver):
         instance = self._get_instance(identity)
 
         os_secure_boot = None
-        if instance.image['id'] is not None:
+        if instance.image.get('id') is not None:
             image = self._get_image_info(instance.image['id'])
             os_secure_boot = getattr(image, 'os_secure_boot', None)
         elif len(instance.attached_volumes) > 0:
@@ -450,15 +461,28 @@ class OpenStackDriver(AbstractSystemsDriver):
             self._logger.debug(msg)
 
         elif boot_image is None:
-            self._logger.debug(
-                'Create task to rebuild with blank-image for %(identity)s' %
-                {'identity': identity})
-            # Not running async here, as long as the blank image used is small
-            # this should finish in ~20 seconds.
-            self._submit_future(
-                False, self._rebuild_with_blank_image, identity)
+            if self._config.get('SUSHY_EMULATOR_OS_VMEDIA_DELAY_EJECT', True):
+                self._logger.debug(
+                    'Set instance metadata for vmedia eject on next power '
+                    'action for %(identity)s' % {'identity': identity})
+                server_metadata = {'sushy-tools-delay-eject': 'true'}
+                self._cc.set_server_metadata(identity, server_metadata)
+            else:
+                self._logger.debug(
+                    'Create task to rebuild with blank-image for '
+                    '%(identity)s' % {'identity': identity})
+                # Not running async here, as long as the blank image used is
+                # small this should finish in ~20 seconds.
+                self._submit_future(
+                    False, self._rebuild_with_blank_image, identity)
 
         else:
+            if self._config.get('SUSHY_EMULATOR_OS_VMEDIA_DELAY_EJECT', True):
+                # Make sure sushy-tools-delay-eject is cleared when media is
+                # inserted. Avoid race in case media is ejected and then
+                # inserted without a power action.
+                self._remove_delayed_eject_metadata(identity)
+
             self._logger.debug(
                 'Creating task to finish import and rebuild for %(identity)s' %
                 {'identity': identity})
@@ -522,8 +546,9 @@ class OpenStackDriver(AbstractSystemsDriver):
         except Exception as ex:
             msg = 'Failed insert image from URL %s: %s' % (image_url, ex)
             self._logger.exception(msg)
+            image_id = image.id if image else None
             self._attempt_delete_image_local_file(
-                image, local_file_path, identity,
+                image_id, local_file_path, identity,
                 'sushy-tools-import-image',
                 'sushy-tools-image-local-file')
             if not isinstance(ex, error.FishyError):
@@ -557,7 +582,7 @@ class OpenStackDriver(AbstractSystemsDriver):
                 raise error.FishyError(msg)
 
             self._attempt_delete_image_local_file(
-                image, None, identity,
+                image.id, None, identity,
                 'sushy-tools-import-image', 'sushy-tools-image-url')
         except Exception as ex:
             msg = 'Failed eject image from URL %s: %s' % (image_url, ex)
@@ -651,7 +676,7 @@ class OpenStackDriver(AbstractSystemsDriver):
             msg = 'Failed insert image from URL %s: %s' % (image_url, ex)
             self._logger.exception(msg)
             self._attempt_delete_image_local_file(
-                image, image_local_file, identity,
+                image.id, image_local_file, identity,
                 'sushy-tools-import-image', 'sushy-tools-image-local-file')
             if not isinstance(ex, error.FishyError):
                 ex = error.FishyError(msg)
@@ -703,3 +728,10 @@ class OpenStackDriver(AbstractSystemsDriver):
             os.remove(local_file)
         except (FileNotFoundError, TypeError):
             pass
+
+    def _remove_delayed_eject_metadata(self, identity):
+        try:
+            self._cc.delete_server_metadata(identity,
+                                            ['sushy-tools-delay-eject'])
+        except Exception:
+            pass
